==> zio-aws-imagebuilder_2.13-5.17.104.12-sources.jar: zio/aws/imagebuilder/model/GetComponentPolicyResponse.scala <==
package zio.aws.imagebuilder.model
import zio.aws.imagebuilder.model.primitives.{
  ResourcePolicyDocument,
  NonEmptyString
}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class GetComponentPolicyResponse(
    requestId: Option[NonEmptyString] = None,
    policy: Option[ResourcePolicyDocument] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.imagebuilder.model.GetComponentPolicyResponse = {
    import GetComponentPolicyResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.imagebuilder.model.GetComponentPolicyResponse
      .builder()
      .optionallyWith(
        requestId.map(value => NonEmptyString.unwrap(value): java.lang.String)
      )(_.requestId)
      .optionallyWith(
        policy.map(value =>
          ResourcePolicyDocument.unwrap(value): java.lang.String
        )
      )(_.policy)
      .build()
  }
  def asReadOnly
      : zio.aws.imagebuilder.model.GetComponentPolicyResponse.ReadOnly =
    zio.aws.imagebuilder.model.GetComponentPolicyResponse.wrap(buildAwsValue())
}
object GetComponentPolicyResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.imagebuilder.model.GetComponentPolicyResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.imagebuilder.model.GetComponentPolicyResponse =
      zio.aws.imagebuilder.model.GetComponentPolicyResponse(
        requestId.map(value => value),
        policy.map(value => value)
      )
    def requestId: Option[NonEmptyString]
    def policy: Option[ResourcePolicyDocument]
    def getRequestId: ZIO[Any, AwsError, NonEmptyString] =
      AwsError.unwrapOptionField("requestId", requestId)
    def getPolicy: ZIO[Any, AwsError, ResourcePolicyDocument] =
      AwsError.unwrapOptionField("policy", policy)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.imagebuilder.model.GetComponentPolicyResponse
  ) extends zio.aws.imagebuilder.model.GetComponentPolicyResponse.ReadOnly {
    override val requestId: Option[NonEmptyString] = scala
      .Option(impl.requestId())
      .map(value => zio.aws.imagebuilder.model.primitives.NonEmptyString(value))
    override val policy: Option[ResourcePolicyDocument] = scala
      .Option(impl.policy())
      .map(value =>
        zio.aws.imagebuilder.model.primitives.ResourcePolicyDocument(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.imagebuilder.model.GetComponentPolicyResponse
  ): zio.aws.imagebuilder.model.GetComponentPolicyResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-imagebuilder_2.13-5.19.31.2-sources.jar: zio/aws/imagebuilder/model/GetComponentPolicyResponse.scala <==
package zio.aws.imagebuilder.model
import zio.aws.imagebuilder.model.primitives.{
  ResourcePolicyDocument,
  NonEmptyString
}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class GetComponentPolicyResponse(
    requestId: Optional[NonEmptyString] = Optional.Absent,
    policy: Optional[ResourcePolicyDocument] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.imagebuilder.model.GetComponentPolicyResponse = {
    import GetComponentPolicyResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.imagebuilder.model.GetComponentPolicyResponse
      .builder()
      .optionallyWith(
        requestId.map(value => NonEmptyString.unwrap(value): java.lang.String)
      )(_.requestId)
      .optionallyWith(
        policy.map(value =>
          ResourcePolicyDocument.unwrap(value): java.lang.String
        )
      )(_.policy)
      .build()
  }
  def asReadOnly
      : zio.aws.imagebuilder.model.GetComponentPolicyResponse.ReadOnly =
    zio.aws.imagebuilder.model.GetComponentPolicyResponse.wrap(buildAwsValue())
}
object GetComponentPolicyResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.imagebuilder.model.GetComponentPolicyResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.imagebuilder.model.GetComponentPolicyResponse =
      zio.aws.imagebuilder.model.GetComponentPolicyResponse(
        requestId.map(value => value),
        policy.map(value => value)
      )
    def requestId: Optional[NonEmptyString]
    def policy: Optional[ResourcePolicyDocument]
    def getRequestId: ZIO[Any, AwsError, NonEmptyString] =
      AwsError.unwrapOptionField("requestId", requestId)
    def getPolicy: ZIO[Any, AwsError, ResourcePolicyDocument] =
      AwsError.unwrapOptionField("policy", policy)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.imagebuilder.model.GetComponentPolicyResponse
  ) extends zio.aws.imagebuilder.model.GetComponentPolicyResponse.ReadOnly {
    override val requestId: Optional[NonEmptyString] = zio.aws.core.internal
      .optionalFromNullable(impl.requestId())
      .map(value => zio.aws.imagebuilder.model.primitives.NonEmptyString(value))
    override val policy: Optional[ResourcePolicyDocument] =
      zio.aws.core.internal
        .optionalFromNullable(impl.policy())
        .map(value =>
          zio.aws.imagebuilder.model.primitives.ResourcePolicyDocument(value)
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.imagebuilder.model.GetComponentPolicyResponse
  ): zio.aws.imagebuilder.model.GetComponentPolicyResponse.ReadOnly =
    new Wrapper(impl)
}
